==> am_mod_grp_0_1.zip: am_mod_grp_0_1/components/grp/template/barnraiser_01/inc/menu_group.inc.php <==
<?php
// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<span class="txt_highlight"><?php echo $lang['menu_label_view'];?>:</span>

&nbsp;

<?php
$link_css = "";
if ($page_name_short == "overview") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=grp_overview"<?php echo $link_css;?>><?php echo $lang['menu_overview'];?></a>
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "list") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=grp_list"<?php echo $link_css;?>><?php echo $lang['menu_groups'];?></a>
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "metadata") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=grp_metadata"<?php echo $link_css;?>><?php echo $lang['menu_cloud'];?></a>
&nbsp;


<?php
if (isset($group)) {
?>

	&#124;
	&nbsp;
	<span class="txt_highlight"><?php echo $lang['menu_label_group'];?>:</span>

	&nbsp;
	<?php
	$link_css = "";
	if ($page_name_short == "item") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=grp_item&group_id=<?php echo $group['group_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_group'];?></a>
	&nbsp;

	<?php
	$link_css = "";
	if ($page_name_short == "participate") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=grp_participation&amp;group_id=<?php echo $group['group_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_participation'];?></a>
	&nbsp;
	
	<?php
	$link_css = "";
	if ($page_name_short == "grp_structure") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=grp_structure&group_id=<?php echo $group['group_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_structure'];?></a>
	&nbsp;
	
	<?php
	if (isset($_SESSION['user_id']) && $group['user_id'] == $_SESSION['user_id']) {
	$link_css = "";
	if ($page_name_short == "grp_manage") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=grp_manage&amp;group_id=<?php echo $group['group_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_manage'];?></a>
	&nbsp;
	<?php }?>

	<?php
	if (isset($participation) && $participation['participation_permission'] & $group_config['resource']['user']['allow_invite']) {
	$link_css = "";
	if ($page_name_short == "invite") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=grp_invite&amp;group_id=<?php echo $group['group_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_invite'];?></a>
	&nbsp;
	<?php }?>
	
	<?php
	$link_css = "";
	if ($page_name_short == "file") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_fil_view&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;item_id=<?php echo $group['group_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_files'];?></a>
	&nbsp;
<?php }?>


<?php
if (!isset($sub_section) && !isset($group)) {
?>
	<?php
	if ($_SESSION['user_mod_permission'] & $resource['module']['grp']['create']) {
	?>
	&#124;
	&nbsp;
	<span class="txt_highlight"><?php echo $lang['menu_label_do'];?>:</span>
	&nbsp;

	<?php
	$link_css = "";
	if ($page_name_short == "edit") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=grp_edit"<?php echo $link_css;?>><?php echo $lang['menu_create'];?></a>
	&nbsp;
	<?php }?>
<?php }?>

==> am_mod_grp_0_3.zip: am_mod_grp_0_3/components/grp/template/barnraiser_01/inc/menu_group.inc.php <==
<?php
// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<span class="txt_highlight"><?php echo $lang['menu_label_view'];?>:</span>

&nbsp;

<?php
$link_css = "";
if ($page_name_short == "overview") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=grp_overview"<?php echo $link_css;?>><?php echo $lang['menu_overview'];?></a>
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "list") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=grp_list"<?php echo $link_css;?>><?php echo $lang['menu_groups'];?></a>
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "metadata") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=grp_metadata"<?php echo $link_css;?>><?php echo $lang['menu_cloud'];?></a>
&nbsp;


<?php
if (isset($group)) {
?>

	&#124;
	&nbsp;
	<span class="txt_highlight"><?php echo $lang['menu_label_group'];?>:</span>

	&nbsp;
	<?php
	$link_css = "";
	if ($page_name_short == "item") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=grp_item&amp;group_id=<?php echo $group['group_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_group'];?></a>
	&nbsp;

	<?php
	if (isset($_SESSION['md5'])) {
	if (($group['group_type'] == $group_config['type']['membership_type']) || ($group['group_type'] != $group_config['type']['invitation'])) {
	$link_css = "";
	if ($page_name_short == "participate") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_participation&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;item_id=<?php echo $group['group_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_participation'];?></a>
	&nbsp;
	<?php }}?>
	
	<?php
	$link_css = "";
	if ($page_name_short == "grp_structure") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=grp_structure&amp;group_id=<?php echo $group['group_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_structure'];?></a>
	&nbsp;
	
	<?php
	if (isset($_SESSION['user_id']) && $group['user_id'] == $_SESSION['user_id']) {
	$link_css = "";
	if ($page_name_short == "manage") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=grp_manage&amp;group_id=<?php echo $group['group_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_manage'];?></a>
	&nbsp;
	<?php }?>

	<?php
	if (isset($participation) && $participation['participation_permission'] & $group_config['resource']['user']['allow_invite']) {
	$link_css = "";
	if ($page_name_short == "invite") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_invite&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;item_id=<?php echo $group['group_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_invite'];?></a>
	&nbsp;
	<?php }?>
	
	<?php
	$link_css = "";
	if ($page_name_short == "file") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_fil_view&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;item_id=<?php echo $group['group_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_files'];?></a>
	&nbsp;
<?php }?>


<?php
if (!isset($sub_section) && !isset($group)) {
?>
	<?php
	if ($_SESSION['user_mod_permission'] & $resource['module']['grp']['create']) {
	?>
	&#124;
	&nbsp;
	<span class="txt_highlight"><?php echo $lang['menu_label_do'];?>:</span>
	&nbsp;

	<?php
	$link_css = "";
	if ($page_name_short == "edit") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=grp_edit"<?php echo $link_css;?>><?php echo $lang['menu_create'];?></a>
	&nbsp;
	<?php }?>
<?php }?>
